@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-@author: Iuliia Baglaeva and Bogdan detrendingIaparov
-"""
+
 import numpy as np
 import pandas as pd
 from scipy.signal import windows, find_peaks
@@ -22,11 +20,11 @@ class TransientAnalyzer:
 
    .. math:: K(x, y) = k(x, y)+ \sigma^2 \delta(x, y),
 
-   where *k(x, y)* is the covariance matrix, &sigma is the noise amplitude and &delta(x, y) is the Kronecker delta. 
+   where :math:'k(x, y)' is the covariance matrix, :math:'\sigma' is the noise amplitude and :math:'\delta(x, y)' is the Kronecker delta. 
 
    Considering the Bayesian framework the aim is to find the posterior distribution - the prior multivariate Gaussian distribution 
    conditioned on the observed data.
-   The covariance matrix *k(x, y)* defines the mutual relationship between all points of the true signal.
+   The covariance matrix :math:'k(x, y)' defines the mutual relationship between all points of the true signal.
     
     Since transients signals are non-stationary processes with fast rise and slow decay the kernel of GP being used is :class:`LinearGibbs`
     """
@@ -463,7 +461,7 @@ class TransientAnalyzer:
         columns = [f"t0{x_out}",f"delta t0{x_out}",f"Baseline{y_out}",f"Amplitude{y_out}",f"TTP{x_out}",
                    f"t({q1}%-{100-q1}%){x_out}",f"t({q2}%-{100-q2}%){x_out}",f"{q1}% Duration{x_out}",
                    f"{q2}% Duration{x_out}",f"50% Duration{x_out}",f"{100-q2}% Duration{x_out}",
-                   f"{100-q1}% Duration{x_out}",f"t({q1}%-{100-q1}%){x_out}",f"t({q2}%-{100-q2}%){x_out}"]
+                   f"{100-q1}% Duration{x_out}",f"t({100-q1}%-{q1}%){x_out}",f"t({100-q2}%-{q2}%){x_out}"]
         pars = np.array(self.parameters)
         pars[1:,1] = pars[1:,0] - pars[:-1,0]
         df = pd.DataFrame(pars,columns=columns)
